#!D:\bld\gdal-split_1618873963298\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.1.4','gdalident.py'
__requires__ = 'GDAL==3.1.4'
__import__('pkg_resources').run_script('GDAL==3.1.4', 'gdalident.py')
